Documentation
¶
Index ¶
- Variables
- func FindProjectRoot() (string, error)
- func GetHTTPClient() *retryablehttp.Client
- func InitHomeDirConfig(sess *session.Session, v *viper.Viper) error
- func ParseHost(arg string) (netip.Addr, error)
- func PrefixProjectRoot(prefix string) (string, error)
- func TrackDuration(mu *sync.Mutex, m map[string]time.Duration, provider string) func()
Constants ¶
This section is empty.
Variables ¶
var ( Version string SemVer string )
Functions ¶
func FindProjectRoot ¶
FindProjectRoot walks up the file tree to find the directory containing `go.mod`
func GetHTTPClient ¶
func GetHTTPClient() *retryablehttp.Client
func ParseHost ¶
ParseHost attempts to convert the provided argument into a netip.Addr. If the argument isn't already an IP address, it is treated as a hostname and resolved using the system resolver.
func PrefixProjectRoot ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.